summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmfinishedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmfinishedit.h')
-rw-r--r--kpovmodeler/pmfinishedit.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/kpovmodeler/pmfinishedit.h b/kpovmodeler/pmfinishedit.h
index e72aef73..9d37ce14 100644
--- a/kpovmodeler/pmfinishedit.h
+++ b/kpovmodeler/pmfinishedit.h
@@ -39,12 +39,13 @@ class TQWidget;
class PMFinishEdit : public PMTextureBaseEdit
{
Q_OBJECT
+ TQ_OBJECT
typedef PMTextureBaseEdit Base;
public:
/**
* Creates a PMFinishEdit with parent and name
*/
- PMFinishEdit( TQWidget* parent, const char* name = 0 );
+ PMFinishEdit( TQWidget* tqparent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -39,12 +39,13 @@ class TQWidget;
public:
/**
- * Creates a PMFinishEdit with parent and name
+ * Creates a PMFinishEdit with tqparent and name
*/